.. :changelog:

History
-------

0.1.1 (2014-06-09)
++++++++++++++++++

- Handle and FK returns link to detail view if exists.

- fixes and tweaks

0.1.0 (2014-06-08)
++++++++++++++++++

* First release on PyPI.
